# -*- coding: utf-8 -*-
from __future__ import absolute_import, division, print_function, unicode_literals
import os.path
try:
    from subprocess import check_output
except ImportError:
    def check_output(*popenargs, **kwargs):  # from python 2.7
        from subprocess import PIPE, Popen, CalledProcessError
        if 'stdout' in kwargs:
            raise ValueError('stdout argument not allowed, it will be overridden.')
        process = Popen(stdout=PIPE, *popenargs, **kwargs)
        output, unused_err = process.communicate()
        retcode = process.poll()
        if retcode:
            cmd = kwargs.get("args")
            if cmd is None:
                cmd = popenargs[0]
            raise CalledProcessError(retcode, cmd, output=output)
        return output

import sphinx_rtd_theme

project = u'zbarlight'
copyright = u'2015, Polyconseil'

version = check_output(
    ['python', 'setup.py', '--version'],
    cwd=os.path.join(os.path.dirname(__file__), '..'),
).decode()
release = version

extensions = ['sphinx.ext.intersphinx', 'sphinx.ext.autodoc', 'sphinx.ext.napoleon']
intersphinx_mapping = {
    'python': ('http://docs.python.org/3', None),
    'pillow': ('http://pillow.readthedocs.org/', None),
}

templates_path = []
source_suffix = '.rst'
master_doc = 'index'

pygments_style = 'sphinx'
html_theme = 'sphinx_rtd_theme'
html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
html_static_path = []



from __future__ import absolute_import, division, print_function, unicode_literals
import warnings

from PIL import Image

from ._zbarlight import zbar_code_scanner


__version__ = '1.0.0'
__ALL__ = ['scan_codes', 'qr_code_scanner']


def scan_codes(code_type, image):
    """Get *code_type* codes from a PIL Image

    *code_type* can be any of zbar supported code type [#zbar_symbologies]_:

    - **EAN/UPC**: EAN-13 (`ean13`), UPC-A (`upca`), EAN-8 (`ean8`) and UPC-E (`upce`)
    - **Linear barcode**: Code 128 (`code128`), Code 93 (`code93`), Code 39 (`code39`), Interleaved 2 of 5 (`i25`),
      DataBar (`databar`) and DataBar Expanded (`databar-exp`)
    - **2D**: QR Code (`qrcode`)
    - **Undocumented**: `ean5`, `ean2`, `composite`, `isbn13`, `isbn10`, `codabar`, `pdf417`

    .. [#zbar_symbologies] http://zbar.sourceforge.net/iphone/userguide/symbologies.html

    Args:
        code_type (str): Code type to search
        image (PIL.Image.Image): Image to scan

    returns:
        A list of *code_type* code values or None
    """
    assert Image.isImageType(image)
    converted_image = image.convert('L')  # Convert image to gray scale (8 bits per pixel).
    raw = converted_image.tobytes()  # Get image data.
    width, height = converted_image.size  # Get image size.
    return zbar_code_scanner('{0}.enable'.format(code_type).encode(), raw, width, height)


def qr_code_scanner(image, width, height):
    """Get QR code from a gray scale image ('Y800' mode)

    If the image has more than one QR code, ``None`` is returned.

    This function is deprecated, use ``scan_codes()`` instead.

    Args:
        image (bytes): Image data
        width (int): Image width
        height (int): Image height

    Returns:
        The QR code value or None
    """
    warnings.warn('qr_code_scanner() is deprecated use scan_codes() instead.', DeprecationWarning)
    result = zbar_code_scanner(b'qrcode.enable', image, width, height)
    if isinstance(result, list) and len(result) == 1:
        return result[0]
    return None



import os.path
import unittest

from PIL import Image

import zbarlight


def zbarlight_image(file_path):
    with open(file_path, 'rb') as image_file:
        image = Image.open(image_file)
        image.load()
    converted_image = image.convert('L')
    image.close()
    return converted_image.tobytes(), converted_image.size


class QRCodeScannerTestCase(unittest.TestCase):
    def assertIsNone(self, obj, msg=None):  # Python 2.6 compatibility
        return self.assertTrue(obj is None, '%s is not None' % repr(obj))

    def get_image(self, name):
        return zbarlight_image(
            os.path.join(os.path.dirname(__file__), 'fixtures', '{0}.png'.format(name))
        )

    def test_no_qr_code(self):
        raw, (width, height) = self.get_image('no_qr_code')
        self.assertIsNone(zbarlight.qr_code_scanner(raw, width, height))

    def test_one_qr_code(self):
        raw, (width, height) = self.get_image('one_qr_code')
        code = zbarlight.qr_code_scanner(raw, width, height)
        self.assertEqual(code, b"zbarlight test qr code")

    def test_two_qr_code(self):
        raw, (width, height) = self.get_image('two_qr_codes')
        self.assertIsNone(zbarlight.qr_code_scanner(raw, width, height))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import absolute_import, division, print_function, unicode_literals
import io
import os
import os.path
import re

from setuptools import setup, find_packages, Extension

PACKAGE = 'zbarlight'


def _open(*file_path):
    here = os.path.abspath(os.path.dirname(__file__))
    return io.open(os.path.join(here, *file_path), 'r', encoding='utf-8')


def get_version(package):
    version_pattern = re.compile(r"^__version__ = [\"']([\w_.-]+)[\"']$", re.MULTILINE)
    with _open(*(package.split('.') + ['__init__.py'])) as version_file:
        matched = version_pattern.search(version_file.read())
    return matched.groups()[0]


def get_long_description():
    with _open('README.rst') as readme_file:
        return readme_file.read()


REQUIREMENTS = [
    'Pillow',
]

setup(
    name=PACKAGE,
    version=get_version(PACKAGE),
    description="A simple zbar wrapper",
    long_description=get_long_description(),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: C',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Scientific/Engineering :: Image Recognition',
    ],
    keywords=['zbar', 'QR code reader'],
    author='Polyconseil',
    author_email='opensource+%s@polyconseil.fr' % PACKAGE,
    url='https://github.com/Polyconseil/%s/' % PACKAGE,
    license='BSD',
    packages=find_packages(exclude=['docs', 'tests']),
    ext_modules=[
        Extension(
            str('zbarlight._zbarlight'),
            [str('zbarlight/_zbarlight.c')],
            extra_compile_args=['-std=c99'],
            libraries=['zbar'],
        ),
    ],
    include_package_data=True,
    zip_safe=False,
    setup_requires=[
        'setuptools',
    ],
    install_requires=REQUIREMENTS,
    tests_require= [
        'docutils',
        'Sphinx',
        'sphinx_rtd_theme',
    ],
    test_suite='tests'
)



import os
import os.path
import shutil
import tempfile
import unittest

from docutils.core import publish_cmdline
from sphinx.cmdline import main as sphinx_cmdline


def test_rst(file_path):
    publish_cmdline(
        writer_name='null',
        argv=['--exit-status=1', '--report=1', file_path]
    )


def test_sphinx(doc_path):
    build_dir = tempfile.mkdtemp()
    return_code = sphinx_cmdline([
        'sphinx-build',
        '-W', '-n', '-q',
        '-b', 'html',
        '-d', os.path.join(build_dir, 'doctrees'),
        doc_path,
        os.path.join(build_dir, 'html')
    ])
    shutil.rmtree(build_dir)
    return return_code


class DocTestCase(unittest.TestCase):
    @staticmethod
    def relative_path(*args):
        return os.path.join(os.path.dirname(__file__), '..', *args)

    def test_readme(self):
        test_rst(self.relative_path('README.rst'))

    def test_changelog(self):
        test_rst(self.relative_path('ChangeLog.rst'))

    def test_docs(self):
        self.assertEqual(test_sphinx(self.relative_path('docs')), 0)
